==> softcorp_flutter_core-1.0.1049.tar.gz: lib/default_dropdown_field/default_dropdown_field.dart <==
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';
import 'package:softcorp_flutter_core/menu_button/menu_button.dart';
import 'package:softcorp_flutter_core/text_theme/text_theme.dart';

import '../constants.dart';

class DefaultDropdownFormField extends StatefulWidget {
  final String label;
  final Function(String? newValue) onChanged;
  final String? value;
  final String hint;
  final bool? disabled;
  final Color? labelColor;
  final IconData? prefixIcon;
  final List<String> items;

  const DefaultDropdownFormField({
    Key? key,
    required this.label,
    required this.onChanged,
    required this.items,
    required this.hint,
    this.value,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DefaultDropdownFormFieldState();
  }
}

class _DefaultDropdownFormFieldState extends State<DefaultDropdownFormField> {
  String? selectedKey;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget normalChildButton(bool isExpanded) => Container(
          height: 50,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(10),
            color: Colors.white,
          ),
          child: Padding(
            padding: const EdgeInsets.only(left: 12, right: 12),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Icon(
                  widget.prefixIcon,
                  color: Colors.black,
                  size: 15,
                ),
                const SizedBox(
                  width: 10,
                ),
                body(
                  text: selectedKey ?? widget.hint,
                  context: context,
                  maxLines: 1,
                  color: (selectedKey != null) ? Colors.black : Colors.grey,
                ),
                const Spacer(),
                const Icon(
                  Icons.arrow_drop_down,
                  color: Colors.black,
                  size: 24,
                ),
              ],
            ),
          ),
        );
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.start,
      children: <Widget>[
        Padding(
          padding: EdgeInsets.only(left: 10),
          child: caption(
            text: widget.label,
            context: context,
            color: widget.labelColor ?? defaultSubTitleColor,
          ),
        ),
        DefaultCard(
          shadowColor: defaultLightShadow,
          child: MenuButton<String>(
            child: normalChildButton(false),
            items: widget.items,
            topDivider: true,
            showSelectedItemOnList: true,
            highlightColor: defaultHoverColor,
            menuButtonBackgroundColor: Colors.transparent,
            divider: const Divider(
              height: 0.1,
            ),
            //showSelectedItemOnList: false,
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
              border: Border.all(color: Colors.transparent),
            ),
            selectedItem: selectedKey,
            itemBuilder: (String value) => Container(
              height: 40,
              alignment: Alignment.centerLeft,
              padding:
                  const EdgeInsets.symmetric(vertical: 0.0, horizontal: 16),
              child: muted(
                  text: value,
                  context: context,
                  color: Colors.black,
                  width: 150),
            ),
            toggledChild: normalChildButton(true),
            onItemSelected: (String? newValue) {
              setState(() {
                selectedKey = newValue;
              });
              widget.onChanged(newValue);
            },
          ),
        ),
      ],
    );
  }
}

==> softcorp_flutter_core-1.0.1051.tar.gz: lib/default_dropdown_field/default_dropdown_field.dart <==
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';
import 'package:softcorp_flutter_core/menu_button/menu_button.dart';
import 'package:softcorp_flutter_core/text_theme/text_theme.dart';

import '../constants.dart';

class DefaultDropdownFormField extends StatefulWidget {
  final String label;
  final Function(String? newValue) onChanged;
  final String? value;
  final String hint;
  final bool? disabled;
  final Color? labelColor;
  final IconData? prefixIcon;
  final List<String> items;
  final double? height;

  const DefaultDropdownFormField({
    Key? key,
    required this.label,
    required this.onChanged,
    required this.items,
    required this.hint,
    this.value,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
    this.height,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DefaultDropdownFormFieldState();
  }
}

class _DefaultDropdownFormFieldState extends State<DefaultDropdownFormField> {
  String? selectedKey;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget normalChildButton(bool isExpanded) => Container(
          height: widget.height ?? defaultFormFieldHeight,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(10),
            color: Colors.white,
          ),
          child: Padding(
            padding: const EdgeInsets.only(left: 12, right: 12),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Icon(
                  widget.prefixIcon,
                  color: Colors.black,
                  size: 15,
                ),
                const SizedBox(
                  width: 10,
                ),
                body(
                  text: selectedKey ?? widget.hint,
                  context: context,
                  maxLines: 1,
                  color: (selectedKey != null) ? Colors.black : Colors.grey,
                ),
                const Spacer(),
                const Icon(
                  Icons.arrow_drop_down,
                  color: Colors.black,
                  size: 24,
                ),
              ],
            ),
          ),
        );
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.start,
      children: <Widget>[
        Padding(
          padding: const EdgeInsets.only(left: 10),
          child: caption(
            text: widget.label,
            context: context,
            color: widget.labelColor ?? defaultSubTitleColor,
          ),
        ),
        DefaultCard(
          shadowColor: defaultLightShadow,
          child: MenuButton<String>(
            child: normalChildButton(false),
            items: widget.items,
            topDivider: true,
            showSelectedItemOnList: true,
            highlightColor: defaultHoverColor,
            menuButtonBackgroundColor: Colors.transparent,
            divider: const Divider(
              height: 0.1,
            ),
            //showSelectedItemOnList: false,
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
              border: Border.all(color: Colors.transparent),
            ),
            selectedItem: selectedKey,
            itemBuilder: (String value) => Container(
              height: 40,
              alignment: Alignment.centerLeft,
              padding:
                  const EdgeInsets.symmetric(vertical: 0.0, horizontal: 16),
              child: muted(
                  text: value,
                  context: context,
                  color: Colors.black,
                  width: 150),
            ),
            toggledChild: normalChildButton(true),
            onItemSelected: (String? newValue) {
              setState(() {
                selectedKey = newValue;
              });
              widget.onChanged(newValue);
            },
          ),
        ),
      ],
    );
  }
}
